# Copyright 2024- Le Filament (https://le-filament.com)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html)


from odoo import fields, models


class EventPartnerFields(models.Model):
    _name = "event.partner.fields"
    _description = "Event Partner Field"
    _rec_name = "display_name"

    display_name = fields.Char(compute="_compute_display_name")
    company_id = fields.Many2one(
        comodel_name="res.company",
        string="Company",
        ondelete="cascade",
        required=True,
    )
    ir_field_id = fields.Many2one(
        comodel_name="ir.model.fields",
        string="Model Field",
        domain="[('readonly', '=', False), ('store', '=', True), "
        "('model_id', '=', 'res.partner'), "
        "('ttype', 'in', ['char', 'text', 'date', 'integer', 'float', 'boolean', "
        "'selection', 'many2one', 'many2many'])]",
        ondelete="cascade",
        required=True,
    )

    # ------------------------------------------------------
    # Default methods
    # ------------------------------------------------------

    # ------------------------------------------------------
    # Computed fields / Search Fields
    # ------------------------------------------------------
    def _compute_display_name(self):
        for field in self:
            field.display_name = field.ir_field_id.field_description or ""

    # ------------------------------------------------------
    # Onchange / Constraints
    # ------------------------------------------------------

    # ------------------------------------------------------
    # CRUD methods (ORM overrides)
    # ------------------------------------------------------

    # ------------------------------------------------------
    # Actions
    # ------------------------------------------------------

    # ------------------------------------------------------
    # Business methods
    # ------------------------------------------------------
