# Copyright 2024- Le Filament (https://le-filament.com)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html)

from odoo import _, api, fields, models
from odoo.exceptions import UserError


class EventPartnerQuestion(models.Model):
    _name = "event.partner.question"
    _description = "Event question related to partner field"
    _order = "sequence,title"

    # ------------------------------------------------------
    # Fields declaration
    # ------------------------------------------------------
    sequence = fields.Integer(default=10)
    title = fields.Char(required=True, translate=True)
    event_type_id = fields.Many2one(
        comodel_name="event.type", string="Event Type", ondelete="cascade"
    )
    event_id = fields.Many2one(
        comodel_name="event.event", string="Event", ondelete="cascade"
    )
    is_mandatory_answer = fields.Boolean(
        "Answer required",
    )
    field_id = fields.Many2one(
        comodel_name="event.partner.fields",
        string="Corresponding field",
        ondelete="cascade",
        required=True,
    )

    # ------------------------------------------------------
    # SQL Constraints
    # ------------------------------------------------------
    _sql_constraints = [
        (
            "_uniq_event_partner_question",
            "UNIQUE (event_id, field_id)",
            _("This field is present more than once in event questions."),
        ),
        (
            "_uniq_event_type_partner_question",
            "UNIQUE (event_type_id, field_id)",
            _("This field is present more than once in event type questions."),
        ),
    ]

    # ------------------------------------------------------
    # API Constraints
    # ------------------------------------------------------
    @api.constrains("event_type_id", "event_id")
    def _constrains_event(self):
        if any(question.event_type_id and question.event_id for question in self):
            raise UserError(
                _("Question cannot be linked to both an Event and an Event Type.")
            )

    # ------------------------------------------------------
    # Default methods
    # ------------------------------------------------------

    # ------------------------------------------------------
    # Computed fields / Search Fields
    # ------------------------------------------------------

    # ------------------------------------------------------
    # Onchange / Constraints
    # ------------------------------------------------------
    @api.onchange("field_id")
    def _onchange_field_id(self):
        for question in self.filtered("field_id"):
            if not question.title:
                question.title = question.field_id.display_name

    # ------------------------------------------------------
    # CRUD methods (ORM overrides)
    # ------------------------------------------------------

    # ------------------------------------------------------
    # Actions
    # ------------------------------------------------------

    # ------------------------------------------------------
    # Business methods
    # ------------------------------------------------------
